"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const chalk_1 = __importDefault(require("chalk"));
exports.createBuiltInBailPlugin = (allowList) => {
    const isbuiltin = require('isbuiltin');
    return {
        name: 'vite:node-built-in-bail',
        resolveId(id, importer) {
            if (isbuiltin(id)) {
                let importingDep;
                if (importer) {
                    const pkg = JSON.parse(utils_1.lookupFile(importer, ['package.json']) || `{}`);
                    if (pkg.name) {
                        importingDep = pkg.name;
                    }
                }
                if (importingDep && allowList && allowList.includes(importingDep)) {
                    return null;
                }
                const dep = importingDep
                    ? `Dependency ${chalk_1.default.yellow(importingDep)}`
                    : `A dependency`;
                throw new Error(`${dep} is attempting to import Node built-in module ${chalk_1.default.yellow(id)}.\n` +
                    `This will not work in a browser environment.\n` +
                    `Imported by: ${chalk_1.default.gray(importer)}`);
            }
            return null;
        }
    };
};
//# sourceMappingURL=pluginBuiltInBail.js.map